@@ -20,14 +20,12 @@ belongs_to network => 'IRC::Schema::Result::Network', 'network_id';
 unique_constraint [qw( name )];
 
 sub test_perl_version { eval <<'EVAL'
-   no if $] > 5.017010, warnings => 'experimental::smartmatch';
-
-   given (1) { when (1) { return 'station' } }
+   feature->import("try"); "station"
 EVAL
 }
 
 sub test_experimental { eval <<'EVAL'
-   sub ($a) { $a + 1}
+   feature->import("try"); 1
 EVAL
 }
 
